# plastik

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

> plt assist, plastic surgery for plt

## Install

`plastik` is available through [PyPI]:

```bash
pip install plastik
```

Installing the development version is done using [poetry]:

```bash
git clone https://github.com/engeir/plastik.git
cd plastik
poetry install
```

## Usage

### Functions

- `dark_theme`
- `topside_legends`

### Classes

- `Ridge`

### Example use

See [examples](./examples/example.py).

## To do

- Add and set up tests in pre-commit

[PyPI]: https://pypi.org/
[poetry]: https://python-poetry.org
